@@ -14,21 +14,24 @@ read.luminex.xls<-function(file,verbose = FALSE,sheets = NULL, assay_id=NULL, na
     require(gdata)
     if(is.null(sheets)) sheets <- try(sheetNames(file,perl = perl))
     if(inherits(sheets,'try-error')) sheets <- 1
+
+    if (verbose) print("read.luminex.xls 200")
+    
     docs <- NULL
     for(i in 1:length(sheets))
         docs[[i]] <- read.luminex.sheet.xls(file, sheet = sheets[i], verbose = verbose, na.strings = na.strings, ..., perl = perl) 
     names(docs) <- sheets
-	
+    
     if(length(docs) == 1)
-		docs <- docs[[1]]
-	else 
-		docs <- do.call(rbind, docs)
+        docs <- docs[[1]]
+    else 
+        docs <- do.call(rbind, docs)
 
     colnames(docs) <- tolower(colnames(docs))
     colnames(docs)[colnames(docs)=="description"]="sample_id"
     colnames(docs)[colnames(docs)=="exp.conc"]="expected_conc"
-    colnames(docs)[colnames(docs)=="type"]="well_role"	
-	
+    colnames(docs)[colnames(docs)=="type"]="well_role"  
+    
     docs$well_role[startsWith(docs$well_role, "X")]="Unknown"
     docs$well_role[startsWith(docs$well_role, "S")]="Standard"
     docs$well_role[startsWith(docs$well_role, "B")]="Background"
@@ -95,6 +98,8 @@ read.luminex.sheet.xls<-function (xls, sheet = 1, lengths = NULL, verbose = FALS
     # if wanted to automatically find the data block and tail block then 
     # should not remove blank lines and should find blank lines - not as easy to do it efficiently in R
     
+    if (verbose) print("read.luminex.sheet.xls 200")
+    
     con <- xls2sep(xls, sheet, verbose = verbose, blank.lines.skip = FALSE, method = 'csv',perl = perl)
     tfn <- summary(con)$description
     close(con)
